@@ -64,7 +64,7 @@ StatHdrLinesFun <- ggproto("StatHdrlinesfun", Stat,
   isobands <- fun_iso(fun, args, normalized, probs, res, rangex, rangey, scales, type = "lines")
 
   names(isobands) <- scales::percent_format(accuracy = 1)(probs)
-  path_df <- iso_to_polygon(isobands, data$group[1])
+  path_df <- iso_to_path(isobands, data$group[1])
   path_df$probs <- ordered(path_df$level, levels = names(isobands))
   path_df$level <- NULL
 
